==> 2.1.1.tar.gz: climate/README.md <==
<p align="center"><img src="http://joe.codes/images/climate/CLImate_Blink.gif" width="300" alt="CLImate" /></p>

[![Latest Version](https://img.shields.io/github/release/thephpleague/climate.svg?style=flat)](https://github.com/thephpleague/climate/releases)
[![Software License](https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](LICENSE.md)
[![Build Status](https://img.shields.io/travis/thephpleague/climate/master.svg?style=flat)](https://travis-ci.org/thephpleague/climate)
[![Coverage Status](https://img.shields.io/scrutinizer/coverage/g/thephpleague/climate.svg?style=flat)](https://scrutinizer-ci.com/g/thephpleague/climate/code-structure)
[![Quality Score](https://img.shields.io/scrutinizer/g/thephpleague/climate.svg?style=flat)](https://scrutinizer-ci.com/g/thephpleague/climate)
[![Total Downloads](https://img.shields.io/packagist/dt/league/climate.svg?style=flat)](https://packagist.org/packages/league/climate)

Running PHP from the command line? CLImate is your new best bud.

CLImate allows you to easily output colored text, special formats, and more.

## Table of Contents

+ [Installation](#installation)
+ [Requirements](#requirements)
+ [Documentation](#documentation)
+ [Credits](#credits)

## Installation

Using [composer](https://packagist.org/packages/league/climate):

```
{
    "require": {
        "league/climate": "~2.0"
    }
}
```

## Requirements

The following versions of PHP are supported by this version.

+ PHP 5.4
+ PHP 5.5
+ PHP 5.6
+ HHVM

## Documentation

CLImate has [full documentation](http://climate.thephpleague.com), powered by [Sculpin](https://sculpin.io).

Contribute to this documentation in the [sculpin branch](https://github.com/thephpleague/climate/tree/gh-pages-sculpin/source).

## Credits

Much love to [Damian Makki](https://dribbble.com/damianmakki) for the logo.

==> 2.3.1.tar.gz: climate/README.md <==
<p align="center"><img src="http://joe.codes/images/climate/CLImate_Blink.gif" width="300" alt="CLImate" /></p>

[![Latest Version](https://img.shields.io/github/release/thephpleague/climate.svg?style=flat)](https://github.com/thephpleague/climate/releases)
[![Software License](https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](LICENSE.md)
[![Build Status](https://img.shields.io/travis/thephpleague/climate/master.svg?style=flat)](https://travis-ci.org/thephpleague/climate)
[![Coverage Status](https://img.shields.io/scrutinizer/coverage/g/thephpleague/climate.svg?style=flat)](https://scrutinizer-ci.com/g/thephpleague/climate/code-structure)
[![Quality Score](https://img.shields.io/scrutinizer/g/thephpleague/climate.svg?style=flat)](https://scrutinizer-ci.com/g/thephpleague/climate)
[![Total Downloads](https://img.shields.io/packagist/dt/league/climate.svg?style=flat)](https://packagist.org/packages/league/climate)

Running PHP from the command line? CLImate is your new best bud.

CLImate allows you to easily output colored text, special formats, and more.

## Table of Contents

+ [Installation](#installation)
+ [Requirements](#requirements)
+ [Documentation](#documentation)
+ [Credits](#credits)

## Installation

Using [composer](https://packagist.org/packages/league/climate):

```
{
    "require": {
        "league/climate": "~2.0"
    }
}
```

## Requirements

The following versions of PHP are supported by this version.

+ PHP 5.4
+ PHP 5.5
+ PHP 5.6
+ HHVM

## Documentation

CLImate has [full documentation](http://climate.thephpleague.com), powered by [Jekyll](http://jekyllrb.com/).

Contribute to this documentation in the [gh-pages branch](https://github.com/thephpleague/climate/tree/gh-pages/).

## Credits

Much love to [Damian Makki](https://dribbble.com/damianmakki) for the logo.
